@@ -11,6 +11,7 @@ package Kernel::Modules::AdminGenericInterfaceTransportHTTPREST;
 
 use strict;
 use warnings;
+use utf8;
 
 use Kernel::System::VariableCheck qw(:all);
 use Kernel::Language qw(Translatable);
@@ -34,9 +35,12 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $ParamObject      = $Kernel::OM->Get('Kernel::System::Web::Request');
-    my $LayoutObject     = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $WebserviceObject = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice');
+    my $ParamObject           = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $LayoutObject          = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $WebserviceObject      = $Kernel::OM->Get('Kernel::System::GenericInterface::Webservice');
+    my $LogObject             = $Kernel::OM->Get('Kernel::System::Log');
+    my $JWTObject             = $Kernel::OM->Get('Kernel::System::JSONWebToken');
+    my $X509CertificateObject = $Kernel::OM->Get('Kernel::System::X509Certificate');
 
     my $WebserviceID      = $ParamObject->GetParam( Param => 'WebserviceID' )      || '';
     my $CommunicationType = $ParamObject->GetParam( Param => 'CommunicationType' ) || '';
@@ -140,6 +144,9 @@ sub Run {
         $TransportConfig->{SSLNoHostnameVerification} = $GetParam->{SSLNoHostnameVerification} || 0;
         $TransportConfig->{ContentType}               = $GetParam->{ContentType};
 
+        my $JWTObjectIsSupported             = $JWTObject->IsSupported();
+        my $X509CertificateObjectIsSupported = $X509CertificateObject->IsSupported();
+
         # Set error for non integer content.
         if ( $GetParam->{Timeout} && !IsInteger( $GetParam->{Timeout} ) ) {
             $Error{TimeoutServerError}        = 'ServerError';
@@ -162,6 +169,144 @@ sub Run {
             }
         }
 
+        # JWT
+        elsif (
+            $GetParam->{AuthType}
+            && $GetParam->{AuthType} eq 'JWT'
+            && $JWTObjectIsSupported
+            )
+        {
+            for my $ParamName (
+                qw(
+                AuthType
+                JWTAuthKeyFilePath JWTAuthKeyFilePassword JWTAuthAlgorithm
+                JWTAuthCertificateFilePath JWTAuthTTL JWTAuthPayload JWTAuthAdditionalHeaderData
+                )
+                )
+            {
+                $TransportConfig->{Authentication}->{$ParamName} = $GetParam->{$ParamName};
+            }
+            NEEDED:
+            for my $Needed (qw( JWTAuthKeyFilePath JWTAuthAlgorithm JWTAuthTTL JWTAuthPayload )) {
+                next NEEDED if defined $GetParam->{$Needed} && length $GetParam->{$Needed};
+
+                $Error{ $Needed . 'ServerError' }        = 'ServerError';
+                $Error{ $Needed . 'ServerErrorMessage' } = Translatable('This field is required');
+            }
+
+            #
+            # Check correct content of fields
+            #
+
+            # Check that a JWT can be generated
+            my $PasswordTestJWT = $JWTObject->Encode(
+                Payload     => {},
+                Algorithm   => 'RS512',
+                KeyFilePath => $GetParam->{JWTAuthKeyFilePath},
+                KeyPassword => $GetParam->{JWTAuthKeyFilePassword},    # might be undef or empty
+            );
+            if ( !$PasswordTestJWT ) {
+                $Error{JWTAuthKeyFilePathServerError} = 'ServerError';
+                $Error{JWTAuthKeyFilePathServerErrorMessage}
+                    = Translatable('Invalid key file and/or password (if needed, see below).');
+
+                if (
+                    defined $GetParam->{JWTAuthKeyFilePassword}
+                    && length $GetParam->{JWTAuthKeyFilePassword}
+                    )
+                {
+                    $Error{JWTAuthKeyFilePasswordServerError} = 'ServerError';
+                    $Error{JWTAuthKeyFilePasswordServerErrorMessage}
+                        = Translatable('Invalid password and/or key file (see above).');
+                }
+            }
+
+            # Check certificate file and set flags for template if invalid or expired.
+            if (
+                $GetParam->{JWTAuthCertificateFilePath}
+                && $X509CertificateObjectIsSupported
+                )
+            {
+                my $X509Certificate = $X509CertificateObject->Parse(
+                    FilePath => $GetParam->{JWTAuthCertificateFilePath},
+                );
+
+                if ( IsHashRefWithData($X509Certificate) ) {
+                    if ( $X509Certificate->{IsExpired} ) {
+                        $Error{JWTAuthCertificateFilePathServerError}        = 'ServerError';
+                        $Error{JWTAuthCertificateFilePathServerErrorMessage} = Translatable('Certificate is expired.');
+                    }
+                }
+                else {
+                    $Error{JWTAuthCertificateFilePathServerError} = 'ServerError';
+                    $Error{JWTAuthCertificateFilePathServerErrorMessage}
+                        = Translatable('Certificate file could not be parsed.');
+                }
+            }
+
+            # TTL must be an integer
+            if ( defined $GetParam->{JWTAuthTTL} && $GetParam->{JWTAuthTTL} !~ m{\A[1-9]\d+\z} ) {
+                $Error{JWTAuthTTLServerError} = 'ServerError';
+                $Error{JWTAuthTTLServerErrorMessage}
+                    = Translatable('Please enter a time in seconds (at least 10 seconds).');
+            }
+
+            # Payload and additional header data must be in correct form (Key1=Value1;Key2=Value2 etc.).
+            FIELDNAME:
+            for my $FieldName (qw(JWTAuthPayload JWTAuthAdditionalHeaderData)) {
+                next FIELDNAME if !IsStringWithData( $GetParam->{$FieldName} );
+
+                my %FieldConfig;
+
+                my @KeyValuePairs = split /\s*;\s*/, $GetParam->{$FieldName};
+
+                KEYVALUEPAIR:
+                for my $KeyValuePair (@KeyValuePairs) {
+                    my @KeyValueParts = split /\s*=\s*/, $KeyValuePair;
+                    if ( @KeyValueParts == 2 ) {
+
+                        # Store as hash instead of string.
+                        $FieldConfig{ $KeyValueParts[0] } = $KeyValueParts[1];
+                        next KEYVALUEPAIR;
+                    }
+
+                    $Error{ $FieldName . 'ServerError' } = 'ServerError';
+                    $Error{ $FieldName . 'ServerErrorMessage' }
+                        = Translatable('Please enter data in expected form (see explanation of field).');
+
+                    next FIELDNAME;
+                }
+
+                # Only set config to hash if there were no errors.
+                # If an error occurs, the entered string will be kept to be displayed again.
+                $TransportConfig->{Authentication}->{$FieldName} = \%FieldConfig;
+            }
+        }
+
+        # OAuth2 token config
+        elsif (
+            $GetParam->{AuthType}
+            && $GetParam->{AuthType} eq 'OAuth2Token'
+            )
+        {
+            for my $ParamName (
+                qw(
+                AuthType
+                OAuth2TokenConfigID
+                )
+                )
+            {
+                $TransportConfig->{Authentication}->{$ParamName} = $GetParam->{$ParamName};
+            }
+            NEEDED:
+            for my $Needed (qw( OAuth2TokenConfigID  )) {
+                next NEEDED if IsStringWithData( $GetParam->{$Needed} );
+
+                $Error{ $Needed . 'ServerError' }        = 'ServerError';
+                $Error{ $Needed . 'ServerErrorMessage' } = Translatable('This field is required');
+            }
+        }
+
         # Check proxy options.
         if ( $GetParam->{UseProxy} && $GetParam->{UseProxy} eq 'Yes' ) {
 
@@ -357,7 +502,21 @@ sub Run {
 sub _ShowEdit {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $LayoutObject            = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $LogObject               = $Kernel::OM->Get('Kernel::System::Log');
+    my $JWTObject               = $Kernel::OM->Get('Kernel::System::JSONWebToken');
+    my $X509CertificateObject   = $Kernel::OM->Get('Kernel::System::X509Certificate');
+    my $OAuth2TokenConfigObject = $Kernel::OM->Get('Kernel::System::OAuth2TokenConfig');
+    my $ValidObject             = $Kernel::OM->Get('Kernel::System::Valid');
+
+    my @ValidIDs = $ValidObject->ValidIDsGet();
+    my $ValidID  = shift @ValidIDs;
+
+    my $JWTObjectIsSupported = $JWTObject->IsSupported();
+    $Param{JWTObjectIsSupported} = $JWTObjectIsSupported;
+
+    my $X509CertificateObjectIsSupported = $X509CertificateObject->IsSupported();
+    $Param{X509CertificateObjectIsSupported} = $X509CertificateObjectIsSupported;
 
     my $Output = $LayoutObject->Header();
     $Output .= $LayoutObject->NavigationBar();
@@ -376,9 +535,34 @@ sub _ShowEdit {
     {
         $Param{$ParamName} = $TransportConfig->{$ParamName};
     }
-    for my $ParamName (qw( AuthType BasicAuthUser BasicAuthPassword )) {
+    for my $ParamName (
+        qw(
+        AuthType
+
+        BasicAuthUser BasicAuthPassword
+
+        JWTAuthKeyFilePath JWTAuthKeyFilePassword JWTAuthAlgorithm
+        JWTAuthCertificateFilePath JWTAuthTTL JWTAuthPayload JWTAuthAdditionalHeaderData
+
+        OAuth2TokenConfigID
+        )
+        )
+    {
         $Param{$ParamName} = $TransportConfig->{Authentication}->{$ParamName};
     }
+
+    # Turn stored hash with JWT payload and additional headers into string for editing.
+    PARAMNAME:
+    for my $ParamName (qw(JWTAuthPayload JWTAuthAdditionalHeaderData)) {
+        next PARAMNAME if !IsHashRefWithData( $TransportConfig->{Authentication}->{$ParamName} );
+
+        $Param{$ParamName} = '';
+        for my $Key ( sort keys %{ $TransportConfig->{Authentication}->{$ParamName} } ) {
+            my $Value = $TransportConfig->{Authentication}->{$ParamName}->{$Key} // '';
+            $Param{$ParamName} .= "$Key=$Value;";
+        }
+    }
+
     for my $ParamName (qw( UseSSL SSLCertificate SSLKey SSLPassword SSLCAFile SSLCADir )) {
         $Param{$ParamName} = $TransportConfig->{SSL}->{$ParamName};
     }
@@ -401,9 +585,9 @@ sub _ShowEdit {
 
         # create ContentType select
         $Param{ContentTypeStrg} = $LayoutObject->BuildSelection(
-            Data          => [ 'JSON', 'FORM' ],
+            Data          => [ 'JSON', 'FORM', 'XML' ],
             Name          => 'ContentType',
-            SelectedValue => $Param{ContentType} || '-',
+            SelectedValue => $Param{ContentType} // '-',
             PossibleNone  => 1,
             Sort          => 'AlphanumericValue',
             Class         => 'Modernize',
@@ -432,23 +616,112 @@ sub _ShowEdit {
         );
 
         # Create Authentication types select.
+        my %AuthTypes = (
+            BasicAuth   => 'BasicAuth',
+            OAuth2Token => 'OAuth2 token',
+        );
+        if ($JWTObjectIsSupported) {
+            $AuthTypes{JWT} = 'JWT';
+        }
+
         $Param{AuthenticationStrg} = $LayoutObject->BuildSelection(
-            Data          => ['BasicAuth'],
-            Name          => 'AuthType',
-            SelectedValue => $Param{AuthType} || '-',
-            PossibleNone  => 1,
-            Sort          => 'AlphanumericValue',
-            Class         => 'Modernize',
+            Data         => \%AuthTypes,
+            Name         => 'AuthType',
+            SelectedID   => $Param{AuthType} || '-',
+            PossibleNone => 1,
+            Sort         => 'AlphanumericValue',
+            Class        => 'Modernize',
+            Translation  => 1,
         );
 
         # Hide and disable authentication methods if they are not selected.
         $Param{BasicAuthHidden} = 'Hidden';
         if ( $Param{AuthType} && $Param{AuthType} eq 'BasicAuth' ) {
             $Param{BasicAuthHidden}                   = '';
-            $Param{BasicAuthUserServerError}          = 'Validate_Required';
+            $Param{BasicAuthUserValidateRequired}     = 'Validate_Required';
             $Param{BasicAuthPasswordValidateRequired} = 'Validate_Required';
         }
 
+        if ($JWTObjectIsSupported) {
+
+            # JWT algorithm selection
+            my @JWTAlgorithms = qw(RS256 RS384 RS512);
+            $Param{JWTAuthAlgorithmStrg} = $LayoutObject->BuildSelection(
+                Data          => \@JWTAlgorithms,
+                Name          => 'JWTAuthAlgorithm',
+                SelectedValue => $Param{JWTAuthAlgorithm},
+                PossibleNone  => 0,
+                Sort          => 'AlphanumericValue',
+                Class         => 'Modernize',
+            );
+
+            # Toggle visibility of JWT authentication options.
+            $Param{JWTAuthHidden} = 'Hidden';
+            if ( $Param{AuthType} && $Param{AuthType} eq 'JWT' ) {
+                $Param{JWTAuthHidden}                      = '';
+                $Param{JWTAuthKeyFilePathValidateRequired} = 'Validate_Required';
+                $Param{JWTAuthAlgorithmValidateRequired}   = 'Validate_Required';
+                $Param{JWTAuthTTLValidateRequired}         = 'Validate_Required';
+                $Param{JWTAuthPayloadValidateRequired}     = 'Validate_Required';
+            }
+
+            # Check that a JWT can be generated
+            if ( $Param{JWTAuthKeyFilePath} ) {
+                my $PasswordTestJWT = $JWTObject->Encode(
+                    Payload     => {},
+                    Algorithm   => 'RS512',
+                    KeyFilePath => $Param{JWTAuthKeyFilePath},
+                    KeyPassword => $Param{JWTAuthKeyFilePassword},    # might be undef or empty
+                );
+                if ( !$PasswordTestJWT ) {
+                    $Param{JWTAuthKeyFilePossibleError} = 1;
+
+                    if (
+                        defined $Param{JWTAuthKeyFilePassword}
+                        && length $Param{JWTAuthKeyFilePassword}
+                        )
+                    {
+                        $Param{JWTAuthKeyFilePasswordPossibleError} = 1;
+                    }
+                }
+            }
+
+            # Check certificate file and set flags for template if invalid or expired.
+            if (
+                $Param{JWTAuthCertificateFilePath}
+                && $X509CertificateObjectIsSupported
+                )
+            {
+                my $X509Certificate = $X509CertificateObject->Parse(
+                    FilePath => $Param{JWTAuthCertificateFilePath},
+                );
+
+                if ( IsHashRefWithData($X509Certificate) ) {
+                    $Param{JWTAuthCertificateFileIsExpired} = $X509Certificate->{IsExpired};
+                }
+                else {
+                    $Param{JWTAuthCertificateFileParseError} = 1;
+                }
+            }
+        }
+
+        # OAuth2 token config selection
+        my @OAuth2TokenConfigs = $OAuth2TokenConfigObject->DataListGet(
+            UserID => $Self->{UserID},
+        );
+        my %OAuthTokenConfigSelection = map { $_->{ID} => $_->{Name} }
+            grep { $_->{ValidID} == $ValidID }
+            @OAuth2TokenConfigs;
+
+        $Param{OAuth2TokenConfigIDStrg} = $LayoutObject->BuildSelection(
+            Data         => \%OAuthTokenConfigSelection,
+            Name         => 'OAuth2TokenConfigID',
+            SelectedID   => $Param{OAuth2TokenConfigID} || '-',
+            PossibleNone => 1,
+            Sort         => 'AlphanumericValue',
+            Class        => 'Modernize',
+        );
+
         # Create use Proxy select.
         $Param{UseProxyStrg} = $LayoutObject->BuildSelection(
             Data => {
@@ -653,6 +926,9 @@ sub _GetParams {
         UseProxy ProxyHost ProxyUser ProxyPassword ProxyExclude
         UseSSL SSLCertificate SSLKey SSLPassword SSLCAFile SSLCADir
         SSLNoHostnameVerification ContentType
+        JWTAuthKeyFilePath JWTAuthKeyFilePassword JWTAuthAlgorithm
+        JWTAuthCertificateFilePath JWTAuthTTL JWTAuthPayload JWTAuthAdditionalHeaderData
+        OAuth2TokenConfigID
         )
         )
     {
