@@ -92,7 +92,7 @@ sub EditFieldRender {
     }
 
     # check and set class if necessary
-    my $FieldClass = 'DynamicFieldText Modernize';
+    my $FieldClass = 'DynamicFieldDropdown Modernize';
     if ( defined $Param{Class} && $Param{Class} ne '' ) {
         $FieldClass .= ' ' . $Param{Class};
     }
@@ -149,28 +149,35 @@ sub EditFieldRender {
             . $TreeSelectionMessage . '</span><i class="fa fa-sitemap"></i></a>';
     }
 
-    # Tooltip for client side validation
-    my $ClientErrorTooltipDivID = $FieldName . 'Error';
-    my $FieldRequiredMessage    = $Param{LayoutObject}->{LanguageObject}->Translate("This field is required.");
-    $HTMLString .= <<"EOF";
-<div id="$ClientErrorTooltipDivID" class="TooltipErrorMessage">
+    if ( $Param{Mandatory} ) {
+        my $DivID = $FieldName . 'Error';
+
+        my $FieldRequiredMessage = $Param{LayoutObject}->{LanguageObject}->Translate("This field is required.");
+
+        # for client side validation
+        $HTMLString .= <<"EOF";
+<div id="$DivID" class="TooltipErrorMessage">
     <p>
         $FieldRequiredMessage
     </p>
 </div>
 EOF
+    }
 
-    # Tooltip for server side validation
-    my $ErrorMessage = $Param{ErrorMessage} || 'This field is required.';
-    $ErrorMessage = $Param{LayoutObject}->{LanguageObject}->Translate($ErrorMessage);
-    my $ServerErrorTooltipDivID = $FieldName . 'ServerError';
-    $HTMLString .= <<"EOF";
-<div id="$ServerErrorTooltipDivID" class="TooltipErrorMessage">
+    if ( $Param{ServerError} ) {
+        my $ErrorMessage = $Param{ErrorMessage} || 'This field is required.';
+        $ErrorMessage = $Param{LayoutObject}->{LanguageObject}->Translate($ErrorMessage);
+        my $DivID = $FieldName . 'ServerError';
+
+        # for server side validation
+        $HTMLString .= <<"EOF";
+<div id="$DivID" class="TooltipErrorMessage">
     <p>
         $ErrorMessage
     </p>
 </div>
 EOF
+    }
 
     my $AutocompleteMinLength = int( $FieldConfig->{AutocompleteMinLength} || 3 );
     my $QueryDelay            = int( $FieldConfig->{QueryDelay}            || 500 );
@@ -194,7 +201,7 @@ EOF
     my $DynamicFieldSearch    = $FieldName . '_Search';
 
     $HTMLString
-        =~ s{(<select )}{$1 data-dynamic-field-name="$DynamicFieldName" data-dynamic-field-type="$DynamicFieldFieldType" data-selected-value-field-name="$FieldName" data-autocomplete-field-name="$DynamicFieldSearch" data-autocomplete-min-length="$AutocompleteMinLength" data-query-delay="$QueryDelay" data-default-search-term="$DefaultSearchTerm" data-ticket-id="$TicketID" };
+        =~ s{(<select )}{$1data-dynamic-field-name="$DynamicFieldName" data-dynamic-field-type="$DynamicFieldFieldType" data-selected-value-field-name="$FieldName" data-autocomplete-field-name="$DynamicFieldSearch" data-autocomplete-min-length="$AutocompleteMinLength" data-query-delay="$QueryDelay" data-default-search-term="$DefaultSearchTerm" data-ticket-id="$TicketID" };
 
     # Add InitSelect for search.
     my $DynamicFieldJS = <<"EOF";
@@ -272,6 +279,10 @@ sub ReadableValueRender {
 
     my $DynamicFieldWebserviceObject = $Kernel::OM->Get('Kernel::System::DynamicField::Webservice');
 
+    $Param{DynamicFieldConfig}->{Config}->{PossibleValues} = $Self->PossibleValuesGet(%Param);
+
+    my $PossibleValues = $Param{DynamicFieldConfig}->{Config}->{PossibleValues};
+
     # set Value and Title variables
     my $Value = '';
     my $Title = '';
@@ -754,10 +765,4 @@ sub StatsSearchFieldParameterBuild {
     return Kernel::System::DynamicField::Driver::BaseSelect::StatsSearchFieldParameterBuild( $Self, %Param );
 }
 
-sub FieldValueValidate {
-    my ( $Self, %Param ) = @_;
-
-    return 1;
-}
-
 1;
