@@ -12,6 +12,7 @@ package scripts::Migration::Znuny::UpgradeDatabaseStructure;    ## no critic
 
 use strict;
 use warnings;
+use utf8;
 
 use parent qw(scripts::Migration::Base);
 
@@ -52,6 +53,18 @@ sub Run {
             Message => 'Add new column color to ticket_state table and also add a default value for initial states.',
             Module  => 'StateColor',
         },
+        {
+            Message => 'Update table smime_keys',
+            Module  => 'SMIME',
+        },
+        {
+            Message => 'Increase size of column of database table calendar_appointment_plugin',
+            Module  => 'CalendarAppointmentID',
+        },
+        {
+            Message => 'Increase size of columns of database table generic_agent_jobs',
+            Module  => 'GenericAgentJobs',
+        },
     );
 
     return 1   if !@Tasks;
