@@ -1,6 +1,6 @@
 // --
 // Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-// Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+// Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (GPL). If you
@@ -71,6 +71,10 @@ Core.UI.RichTextEditor = (function (TargetNS) {
     function InitAutocompletion(Editor) {
         var AutocompletionSettings = {};
 
+        // CodeMirror does not load any other plugins, so the autocomplete plugin is not available then
+        if (Core.Config.Get('RichText.Type') == 'CodeMirror') {
+            return;
+        }
 
         function AutocompletionDataCallback(MatchInfo, Callback) {
             $.each(AutocompletionSettings.Triggers, function (Trigger) {
@@ -303,29 +307,33 @@ Core.UI.RichTextEditor = (function (TargetNS) {
 
         // set default editor config, but allow custom config for other types for editors
         /*eslint-disable camelcase */
-        RemovedCKEditorPlugins = CheckFormID($EditorArea).length ? 'image' : 'image,uploadimage';
-        RemovedCKEditorPlugins += ',elementspath';
+        RemovedCKEditorPlugins = 'devtools,image,flash,mathjax,embed,exportpdf,sourcedialog,bbcode,divarea,elementspath,stylesheetparser';
+        if (!CheckFormID($EditorArea).length) {
+            RemovedCKEditorPlugins += ',uploadimage';
+        }
 
         EditorConfig = {
-            customConfig:              '', // avoid loading external config files
+            // customConfig:              '', // avoid loading external config files
             disableNativeSpellChecker: false,
             defaultLanguage:           UserLanguage,
             language:                  UserLanguage,
             width:                     Core.Config.Get('RichText.Width', 620),
             resize_minWidth:           Core.Config.Get('RichText.Width', 620),
             height:                    Core.Config.Get('RichText.Height', 320),
+            autoGrow_minHeight:        Core.Config.Get('RichText.Height', 320),
             removePlugins:             RemovedCKEditorPlugins,
             forcePasteAsPlainText:     false,
-            format_tags:               'p;h1;h2;h3;h4;h5;h6;pre',
-            fontSize_sizes:            '8px;10px;12px;16px;18px;20px;22px;24px;26px;28px;30px;',
-            extraAllowedContent:       'div[type]{*}; img[*]; col[width]; style[*]{*}; *[id](*)',
+            format_tags:               Core.Config.Get('RichText.FormatTags', 'p;h1;h2;h3;h4;h5;h6;pre'),
+            fontSize_sizes:            Core.Config.Get('RichText.FontSizes', '8px;10px;12px;14px;16px;18px;20px;22px;24px;26px;28px;30px;'),
+            font_names:                Core.Config.Get('RichText.FontNames', ''),
+            extraAllowedContent:       Core.Config.Get('RichText.ExtraAllowedContent', 'div[type]{*}; img[*]; col[width]; style[*]{*}; *[id](*)'),
             enterMode:                 CKEDITOR.ENTER_BR,
             shiftEnterMode:            CKEDITOR.ENTER_BR,
             contentsLangDirection:     Core.Config.Get('RichText.TextDir', 'ltr'),
             toolbar:                   CheckFormID($EditorArea).length ? Core.Config.Get('RichText.Toolbar') : Core.Config.Get('RichText.ToolbarWithoutImage'),
             filebrowserBrowseUrl:      '',
             filebrowserUploadUrl:      UploadURL,
-            extraPlugins:              'splitquote,contextmenu_linkopen,textwatcher,autocomplete,textmatch,autolink,image2,mentions',
+            extraPlugins:              Core.Config.Get('RichText.ExtraPlugins', 'splitquote,contextmenu_linkopen'),
             entities:                  false,
             skin:                      'moono-lisa'
         };
@@ -414,14 +422,6 @@ Core.UI.RichTextEditor = (function (TargetNS) {
             };
             /* eslint-enable no-unused-vars */
 
-            // Needed for clientside validation of RTE
-            CKEDITOR.instances[EditorID].on('blur', function () {
-                CKEDITOR.instances[EditorID].updateElement();
-                if (!$EditorArea.hasClass('Error')) {
-                    Core.Form.Validate.ValidateElement($EditorArea);
-                }
-            });
-
             // needed for client-side validation
             CKEDITOR.instances[EditorID].on('focus', function () {
 
